@@ -36,6 +36,7 @@
 #define vtkMapper_h
 
 #include "vtkAbstractMapper3D.h"
+#include "vtkDeprecation.h"         // For VTK_DEPRECATED_IN_9_5_0
 #include "vtkRenderingCoreModule.h" // For export macro
 #include "vtkSmartPointer.h"        // needed for vtkSmartPointer.
 #include "vtkSystemIncludes.h"      // For VTK_COLOR_MODE_DEFAULT and _MAP_SCALARS
@@ -414,13 +415,17 @@ public:
    */
   vtkDataSet* GetInput();
 
+  ///@{
   /**
    * Get the input to this mapper as a vtkDataSet, instead of as a
    * more specialized data type that the subclass may return from
    * GetInput().  This method is provided for use in the wrapper languages,
    * C++ programmers should use GetInput() instead.
    */
-  vtkDataSet* GetInputAsDataSet() { return this->GetInput(); }
+  vtkDataSet* GetDataSetInput() { return this->GetInput(); }
+  VTK_DEPRECATED_IN_9_5_0("Use GetDataSetInput() instead.")
+  vtkDataSet* GetInputAsDataSet() { return this->GetDataSetInput(); }
+  ///@}
 
   ///@{
   /**
